@@ -13,12 +13,8 @@ use crate::messaging::{
     SectionAuthorityProvider,
 };
 use crate::routing::{
-    dkg::SectionAuthUtils,
-    error::Result,
-    peer::PeerUtils,
-    routing_api::command::Command,
-    section::{ElderCandidatesUtils, SectionPeersUtils},
-    Event, SectionAuthorityProviderUtils, MIN_AGE,
+    dkg::SectionAuthUtils, error::Result, peer::PeerUtils, routing_api::command::Command,
+    section::ElderCandidatesUtils, Event, SectionAuthorityProviderUtils, MIN_AGE,
 };
 
 use super::Core;
